@@ -6,98 +6,138 @@
 #' @param method either "shannon" or "frequency" for Shannon information or relative frequency of element by position.
 #' @param weight numeric variable of weights
 #' @return data frame with position, element and information value
-#' @import plyr
 #' @export
 #' @examples 
 #' \donttest{
 #' library(ggplot2)
 #' data(sequences)
 #' 
-#' ggplot(data = ggfortify(sequences, "peptide", treatment = "class")) +
+#' ggplot(data = ggfortify(sequences, peptide, treatment = class)) +
 #'   geom_logo(aes(x = class, y = bits, fill = Water, label = element)) + 
 #'   facet_wrap(~position)
 #'   
-#' ggplot(data = ggfortify(sequences, "peptide", treatment = "class")) +
+#' ggplot(data = ggfortify(sequences, peptide, treatment = class)) +
 #'   geom_logo(aes(x = class, y = bits, fill = Polarity, label = element)) + 
 #'   facet_wrap(~position, ncol = 18) + 
 #'   theme(legend.position = "bottom")
 #'}
 ggfortify <- function(data, sequences, treatment = NULL, weight = NULL, method = "shannon") {
-    aacids <- NULL
-  dm2 <- splitSequence(data, sequences)
-  k <- 4
-  if (length(unique(dm2$element))>5) k <- 21
-  dm3 <- calcInformation(dm2, pos="position", trt=treatment, weight = weight, elems="element", k=k, method = method)
+  aacids <- NULL
+  position <- NULL
+  element <- NULL
+  
   data(aacids, envir = environment())
   
+  seqs <- enquo(sequences)
+  treatment <- enquo(treatment)
+  weight <- enquo(weight)
+  
+  dm2 <- splitSequence(data, !!seqs)
+  
+  k <- 4
+  if (length(unique(dm2$element)) > 5) k <- 21
+  
+  dm3 <- calcInformation(dm2, pos = position, elems = element, trt = !!treatment, 
+                         weight = !!weight, k = k, method = method)
+  
   if (k == 21) # add peptide informatio only for peptides
     dm3 <- merge(dm3, aacids[,-1], by.x="element", by.y="AA", all.x = TRUE)
-  dm3
+  
+  return(dm3)
 }
  
 #' Reshape data set according to elements in sequences
 #' 
 #' prepare data set for plotting in a logo
 #' @param dframe data frame of peptide (or any other) sequences and some treatment factors
-#' @param sequences character string or index for the character vector of (peptide) sequence
+#' @param sequences column containing the character vector of (peptide) sequence
 #' @export
-#' @importFrom plyr ldply
-#' @importFrom reshape2 melt
+#' @importFrom dplyr mutate
+#' @importFrom dplyr mutate_at
+#' @importFrom dplyr mutate_all
+#' @importFrom tidyr unnest
 #' @examples
 #' data(sequences)
-#' dm2 <- splitSequence(sequences, "peptide")
+#' dm2 <- splitSequence(sequences, peptide)
 splitSequence <- function(dframe, sequences) {
-  seqs <- as.character(dframe[,sequences])
-  seqVars <-  data.frame(dframe, ldply(seqs, function(x) unlist(strsplit(x, split=""))))
-  dm <- melt(seqVars, id.vars=names(dframe))
-  names(dm) <- c(names(dframe), "position", "element")
-  levels(dm$position) <- gsub("V"," ", levels(dm$position))
-  dm
+  position <- NULL
+  element <- NULL
+  
+  seqs <- enquo(sequences)
+  
+  dframe %>%
+    mutate_at(vars(!!seqs), as.character) %>%
+    mutate(position = list(1:nchar(!!seqs)[1]),
+           element = strsplit(!!seqs, split = ""))  %>%
+    unnest() %>%
+    mutate_at(vars(position, element), as.factor)
 }
 
 #' Compute shannon information based on position and treatment
 #' 
 #' @param dframe data frame of peptide (or any other) sequences and some treatment factors
 #' @param trt (vector of) character string(s) of treatment information
-#' @param pos character string of position
-#' @param elems character string of elements
+#' @param pos variable containing position
+#' @param elems variable containing elements
 #' @param k alphabet size: 4 for DNA/RNA sequences, 21 for standard amino acids
-#' @param weight number of times each sequence is observed, defaults to 1 in case no weight is given
+#' @param weight variable containing number of times each sequence is observed, defaults to 1 in case no weight is given
 #' @param method either "shannon" or "frequency" for Shannon information or relative frequency of element by position.
 #' @return extended data frame with additional information of shannon info in bits and each elements contribution to the total information
-#' @importFrom plyr ddply
+#' @importFrom dplyr mutate
+#' @importFrom dplyr summarise
+#' @importFrom dplyr ungroup
+#' @importFrom dplyr select
+#' @importFrom rlang quo_is_null
 #' @export
 #' @examples
 #' data(sequences)
-#' dm2 <- splitSequence(sequences, "peptide")
-#' dm3 <- calcInformation(dm2, pos="position", trt="class", elems="element", k=21)
+#' dm2 <- splitSequence(sequences, peptide)
+#' dm3 <- calcInformation(dm2, pos = position, elems = element, trt = class, k = 21)
 #' # precursor to a logo plot:
 #' library(ggplot2)
 #' # library(biovizBase)
 #' 
-calcInformation <- function(dframe, trt=NULL, pos, elems, k=4, weight = NULL, method="shannon") {
-  if (is.null(weight)) dframe$wt <- 1
-  else dframe$wt <- dframe[,weight]
-  trt <- as.quoted(trt)
-  pos <- as.quoted(pos)
-  elems <- as.quoted(elems)
-  freqs <- ddply(dframe, c(trt, pos, elems), function(x) sum(x$wt))
-## define implicit bindings for variables - not necessary though, since all of the variables do exist
-  freq <- NA
-  total <- NA
+calcInformation <- function(dframe, pos, elems, trt = NULL, weight = NULL, k = 4, method = "shannon") {
+  `_default` <- NULL
+  freq <- NULL
+  total <- NULL
+  info <- NULL
+  bits <- NULL
+  
+  weightqo <- enquo(weight)
+  if (quo_is_null(enquo(weight))) weightqo <- quo(`_default`)
+  
+  trtqo <- enquo(trt)
+  if (quo_is_null(enquo(trt))) trtqo <- quo(`_default`)
+  
+  posqo <- enquo(pos)
+  elemqo <- enquo(elems)
+  
+  freqs <- dframe %>%
+    mutate(`_default` = 1) %>%
+    group_by(!!trtqo, !!posqo, !!elemqo) %>%
+    summarise(freq = sum(!!weightqo))
+  
+  freqByPos <- freqs %>%
+    group_by(!!trtqo, !!posqo) %>%
+    mutate(total = sum(freq))
   
-  names(freqs)[ncol(freqs)] <- "freq"
-  freqByPos <- ddply(freqs, c(trt, pos), transform, total=sum(freq))
   if (method == "shannon") {
-    freqByPos <- ddply(freqByPos, c(trt, pos), transform, info=-sum((freq/total*log(freq/total, base=2))[freq>0]))
-    freqByPos$info <- -log(1/k, base=2) - with(freqByPos, info)
-    freqByPos$bits <- with(freqByPos, freq/total*info) # why bits and not info?
-    freqByPos$info <- freqByPos$bits
-  }  
-  if (method == "frequency")
+    freqByPos <- freqByPos %>%
+      group_by(!!trtqo, !!posqo) %>%
+      mutate(info = -sum((freq/total * log(freq/total, base=2))[freq>0])) %>%
+      mutate(info = -log(1/k, base = 2) - info, bits = freq/total * info) %>%
+      mutate(info = bits) # why bits and not info?
+  } else if (method == "frequency") {
     freqByPos$info <- with(freqByPos, freq/total)
+  }
   
-  freqByPos
+  final <- freqByPos %>%
+    ungroup()
+  
+  if (quo_is_null(enquo(trt))) final <- final %>% select(-`_default`)
+  
+  return(final)
 }
 
 #' Logo plot
@@ -119,13 +159,12 @@ logo <- function(sequences) {
   element <- NA
   
   dframe <- data.frame(seq=sequences)
-  dm2 <- splitSequence(dframe, "seq")
-  dm3 <- calcInformation(dm2, pos="position", elems="element", k=length(unique(dm2$element)))
+  dm2 <- splitSequence(dframe, seq)
+  dm3 <- calcInformation(dm2, pos = position, elems = element, k = length(unique(dm2$element)))
   ggplot(dm3, aes(x=position, y=bits, group=element, label=element)) + geom_logo() 
 }
 
 #' @rdname stat_logo
-#' @import plyr 
 #' @return  proto object
 #' @export 
 #' 
@@ -170,7 +209,7 @@ StatLogo <- ggproto("StatLogo", Stat,
 #' data(sequences)
 #' library(ggplot2)
 #' 
-#' ggplot(data = ggfortify(sequences, "peptide")) + 
+#' ggplot(data = ggfortify(sequences, peptide)) + 
 #'   geom_logo(aes(x=position, y=bits, label=element, 
 #'                 group=interaction(position, element)), 
 #'             alpha=0.5)
@@ -186,6 +225,7 @@ stat_logo <- function(mapping = NULL, data = NULL, geom = "logo",
 #' @rdname geom_logo
 #' @export
 #' @importFrom grid grobTree
+#' @importFrom plyr adply
 GeomLogo <- ggproto("GeomLogo", Geom,
   required_aes = c("x", "y", "group", "label"),
   default_aes = aes(weight = 1, colour = "grey80", fill = "white", size = 0.1, alpha = 0.25, width = 0.9, shape = 16, linetype = "solid"),
@@ -256,24 +296,24 @@ GeomLogo <- ggproto("GeomLogo", Geom,
 #' \donttest{
 #' library(ggplot2)
 #' data(sequences)
-#' ggplot(data = ggfortify(sequences, "peptide")) +      
+#' ggplot(data = ggfortify(sequences, peptide)) +      
 #'   geom_logo(aes(x=position, y=bits, group=element, 
 #'      label=element, fill=interaction(Polarity, Water)),
 #'      alpha = 0.6)  +
 #'   scale_fill_brewer(palette="Paired") +
 #'   theme(legend.position = "bottom")
 #'   
-#' ggplot(data = ggfortify(sequences, "peptide", treatment = "class")) + 
+#' ggplot(data = ggfortify(sequences, peptide, treatment = class)) + 
 #'   geom_logo(aes(x=class, y=bits, group=element, 
 #'      label=element, fill=element)) + 
 #'   facet_wrap(~position, ncol=18) +
 #'   theme(legend.position = "bottom")
 #'   
-#' ggplot(data = ggfortify(sequences, "peptide", treatment = "class")) + 
+#' ggplot(data = ggfortify(sequences, peptide, treatment = class)) + 
 #'   geom_logo(aes(x=position, y=bits, group=element, label=element, fill=element)) + 
 #'   facet_wrap(~class, ncol=1) + theme_bw()
 #'   
-#' ggplot(data = ggfortify(sequences, "peptide", treatment = "class")) + 
+#' ggplot(data = ggfortify(sequences, peptide, treatment = class)) + 
 #'   geom_logo(aes(x=class, y=bits, group=element, 
 #'                 label=element, fill=interaction(Polarity, Water))) + 
 #'   scale_fill_brewer("Amino-acids properties", palette="Paired") + 
